@@ -98,183 +98,183 @@
 
 #define TABLE_DEFINE(table)                                                                        \
     void table##_set_table_box(table *self, int val) {                                             \
-        LOCK(self->table_box((Fl_Boxtype)val);)                                                    \
+        LOCK(self->table_box((Fl_Boxtype)val));                                                    \
     }                                                                                              \
     int table##_table_box(table *self) {                                                           \
-        LOCK(auto ret = self->table_box(););                                                       \
+        LOCK(auto ret = self->table_box());;                                                       \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_rows(table *self, int val) {                                                  \
-        LOCK(self->rows(val);)                                                                     \
+        LOCK(self->rows(val));                                                                     \
     }                                                                                              \
     int table##_rows(table *self) {                                                                \
-        LOCK(auto ret = self->rows(););                                                            \
+        LOCK(auto ret = self->rows());;                                                            \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_cols(table *self, int val) {                                                  \
-        LOCK(self->cols(val);)                                                                     \
+        LOCK(self->cols(val));                                                                     \
     }                                                                                              \
     int table##_cols(table *self) {                                                                \
-        LOCK(auto ret = self->cols(););                                                            \
+        LOCK(auto ret = self->cols());;                                                            \
         return ret;                                                                                \
     }                                                                                              \
     void table##_visible_cells(table *self, int *r1, int *r2, int *c1, int *c2) {                  \
-        LOCK(self->visible_cells(*r1, *r2, *c1, *c2);)                                             \
+        LOCK(self->visible_cells(*r1, *r2, *c1, *c2));                                             \
     }                                                                                              \
     int table##_is_interactive_resize(table *self) {                                               \
-        LOCK(auto ret = self->is_interactive_resize(););                                           \
+        LOCK(auto ret = self->is_interactive_resize());;                                           \
         return ret;                                                                                \
     }                                                                                              \
     int table##_row_resize(table *self) {                                                          \
-        LOCK(auto ret = self->row_resize(););                                                      \
+        LOCK(auto ret = self->row_resize());;                                                      \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_resize(table *self, int flag) {                                           \
-        LOCK(self->row_resize(flag);)                                                              \
+        LOCK(self->row_resize(flag));                                                              \
     }                                                                                              \
     int table##_col_resize(table *self) {                                                          \
-        LOCK(auto ret = self->col_resize(););                                                      \
+        LOCK(auto ret = self->col_resize());;                                                      \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_resize(table *self, int flag) {                                           \
-        LOCK(self->col_resize(flag);)                                                              \
+        LOCK(self->col_resize(flag));                                                              \
     }                                                                                              \
     int table##_col_resize_min(table *self) {                                                      \
-        LOCK(auto ret = self->col_resize_min(););                                                  \
+        LOCK(auto ret = self->col_resize_min());;                                                  \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_resize_min(table *self, int val) {                                        \
-        LOCK(self->col_resize_min(val);)                                                           \
+        LOCK(self->col_resize_min(val));                                                           \
     }                                                                                              \
     int table##_row_resize_min(table *self) {                                                      \
-        LOCK(auto ret = self->row_resize_min(););                                                  \
+        LOCK(auto ret = self->row_resize_min());;                                                  \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_resize_min(table *self, int val) {                                        \
-        LOCK(self->row_resize_min(val);)                                                           \
+        LOCK(self->row_resize_min(val));                                                           \
     }                                                                                              \
     int table##_row_header(table *self) {                                                          \
-        LOCK(auto ret = self->row_header(););                                                      \
+        LOCK(auto ret = self->row_header());;                                                      \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_header(table *self, int flag) {                                           \
-        LOCK(self->row_header(flag);)                                                              \
+        LOCK(self->row_header(flag));                                                              \
     }                                                                                              \
     int table##_col_header(table *self) {                                                          \
-        LOCK(auto ret = self->col_header(););                                                      \
+        LOCK(auto ret = self->col_header());;                                                      \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_header(table *self, int flag) {                                           \
-        LOCK(self->col_header(flag);)                                                              \
+        LOCK(self->col_header(flag));                                                              \
     }                                                                                              \
     void table##_set_col_header_height(table *self, int height) {                                  \
-        LOCK(self->col_header_height(height);)                                                     \
+        LOCK(self->col_header_height(height));                                                     \
     }                                                                                              \
     int table##_col_header_height(table *self) {                                                   \
-        LOCK(auto ret = self->col_header_height(););                                               \
+        LOCK(auto ret = self->col_header_height());;                                               \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_header_width(table *self, int width) {                                    \
-        LOCK(self->row_header_width(width);)                                                       \
+        LOCK(self->row_header_width(width));                                                       \
     }                                                                                              \
     int table##_row_header_width(table *self) {                                                    \
-        LOCK(auto ret = self->row_header_width(););                                                \
+        LOCK(auto ret = self->row_header_width());;                                                \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_header_color(table *self, unsigned int val) {                             \
-        LOCK(self->row_header_color(val);)                                                         \
+        LOCK(self->row_header_color(val));                                                         \
     }                                                                                              \
     unsigned int table##_row_header_color(table *self) {                                           \
-        LOCK(auto ret = self->row_header_color(););                                                \
+        LOCK(auto ret = self->row_header_color());;                                                \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_header_color(table *self, unsigned int val) {                             \
-        LOCK(self->col_header_color(val);)                                                         \
+        LOCK(self->col_header_color(val));                                                         \
     }                                                                                              \
     unsigned int table##_col_header_color(table *self) {                                           \
-        LOCK(auto ret = self->col_header_color(););                                                \
+        LOCK(auto ret = self->col_header_color());;                                                \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_height(table *self, int row, int height) {                                \
-        LOCK(self->row_height(row, height);)                                                       \
+        LOCK(self->row_height(row, height));                                                       \
     }                                                                                              \
     int table##_row_height(table *self, int row) {                                                 \
-        LOCK(auto ret = self->row_height(row););                                                   \
+        LOCK(auto ret = self->row_height(row));;                                                   \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_col_width(table *self, int col, int width) {                                  \
-        LOCK(self->col_width(col, width);)                                                         \
+        LOCK(self->col_width(col, width));                                                         \
     }                                                                                              \
     int table##_col_width(table *self, int col) {                                                  \
-        LOCK(auto ret = self->col_width(col););                                                    \
+        LOCK(auto ret = self->col_width(col));;                                                    \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_row_height_all(table *self, int height) {                                     \
-        LOCK(self->row_height_all(height);)                                                        \
+        LOCK(self->row_height_all(height));                                                        \
     }                                                                                              \
     void table##_set_col_width_all(table *self, int width) {                                       \
-        LOCK(self->col_width_all(width);)                                                          \
+        LOCK(self->col_width_all(width));                                                          \
     }                                                                                              \
     void table##_set_row_position(table *self, int row) {                                          \
-        LOCK(self->row_position(row);)                                                             \
+        LOCK(self->row_position(row));                                                             \
     }                                                                                              \
     void table##_set_col_position(table *self, int col) {                                          \
-        LOCK(self->col_position(col);)                                                             \
+        LOCK(self->col_position(col));                                                             \
     }                                                                                              \
     int table##_row_position(table *self) {                                                        \
-        LOCK(auto ret = self->row_position(););                                                    \
+        LOCK(auto ret = self->row_position());;                                                    \
         return ret;                                                                                \
     }                                                                                              \
     int table##_col_position(table *self) {                                                        \
-        LOCK(auto ret = self->col_position(););                                                    \
+        LOCK(auto ret = self->col_position());;                                                    \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_top_row(table *self, int row) {                                               \
-        LOCK(self->top_row(row);)                                                                  \
+        LOCK(self->top_row(row));                                                                  \
     }                                                                                              \
     int table##_top_row(table *self) {                                                             \
-        LOCK(auto ret = self->top_row(););                                                         \
+        LOCK(auto ret = self->top_row());;                                                         \
         return ret;                                                                                \
     }                                                                                              \
     int table##_is_selected(table *self, int r, int c) {                                           \
-        LOCK(auto ret = self->is_selected(r, c););                                                 \
+        LOCK(auto ret = self->is_selected(r, c));;                                                 \
         return ret;                                                                                \
     }                                                                                              \
     void table##_get_selection(table *self, int *row_top, int *col_left, int *row_bot,             \
                                int *col_right) {                                                   \
-        LOCK(self->get_selection(*row_top, *col_left, *row_bot, *col_right);)                      \
+        LOCK(self->get_selection(*row_top, *col_left, *row_bot, *col_right));                      \
     }                                                                                              \
     void table##_set_selection(table *self, int row_top, int col_left, int row_bot,                \
                                int col_right) {                                                    \
-        LOCK(self->set_selection(row_top, col_left, row_bot, col_right);)                          \
+        LOCK(self->set_selection(row_top, col_left, row_bot, col_right));                          \
     }                                                                                              \
     int table##_move_cursor_with_shiftselect(table *self, int R, int C, int shiftselect) {         \
-        LOCK(auto ret = self->move_cursor(R, C, shiftselect););                                    \
+        LOCK(auto ret = self->move_cursor(R, C, shiftselect));;                                    \
         return ret;                                                                                \
     }                                                                                              \
     int table##_move_cursor(table *self, int R, int C) {                                           \
-        LOCK(auto ret = self->move_cursor(R, C););                                                 \
+        LOCK(auto ret = self->move_cursor(R, C));;                                                 \
         return ret;                                                                                \
     }                                                                                              \
     int table##_scrollbar_size(const table *self) {                                                \
-        LOCK(auto ret = self->scrollbar_size(););                                                  \
+        LOCK(auto ret = self->scrollbar_size());;                                                  \
         return ret;                                                                                \
     }                                                                                              \
     void table##_set_scrollbar_size(table *self, int newSize) {                                    \
-        LOCK(self->scrollbar_size(newSize);)                                                       \
+        LOCK(self->scrollbar_size(newSize));                                                       \
     }                                                                                              \
     void table##_set_tab_cell_nav(table *self, int val) {                                          \
-        LOCK(self->tab_cell_nav(val);)                                                             \
+        LOCK(self->tab_cell_nav(val));                                                             \
     }                                                                                              \
     int table##_tab_cell_nav(const table *self) {                                                  \
-        LOCK(auto ret = self->tab_cell_nav(););                                                    \
+        LOCK(auto ret = self->tab_cell_nav());;                                                    \
         return ret;                                                                                \
     }                                                                                              \
     void table##_draw_cell(table *self,                                                            \
                            void (*cb)(Fl_Widget *, int, int, int, int, int, int, int, void *),     \
                            void *data) {                                                           \
         LOCK(((table##_Derived *)self)->set_cell_drawer_data(data);                                \
-             ((table##_Derived *)self)->set_cell_drawer(cb);)                                      \
+             ((table##_Derived *)self)->set_cell_drawer(cb));                                      \
     }                                                                                              \
     void *table##_draw_cell_data(const table *self) {                                              \
         LOCK(auto ret = ((table##_Derived *)self)->draw_cell_data_);                               \
@@ -284,15 +284,15 @@
         LOCK(((table##_Derived *)self)->draw_cell_data_ = data)                                    \
     }                                                                                              \
     int table##_callback_col(table *self) {                                                        \
-        LOCK(auto ret = self->callback_col(););                                                    \
+        LOCK(auto ret = self->callback_col());;                                                    \
         return ret;                                                                                \
     }                                                                                              \
     int table##_callback_row(table *self) {                                                        \
-        LOCK(auto ret = self->callback_row(););                                                    \
+        LOCK(auto ret = self->callback_row());;                                                    \
         return ret;                                                                                \
     }                                                                                              \
     int table##_callback_context(table *self) {                                                    \
-        LOCK(auto ret = self->callback_context(););                                                \
+        LOCK(auto ret = self->callback_context());;                                                \
         return ret;                                                                                \
     }                                                                                              \
     void *table##_scrollbar(const table *self) {                                                   \
@@ -326,10 +326,10 @@ int Fl_Table_Row_row_selected(Fl_Table_Row *self, int row) {
 }
 
 int Fl_Table_Row_select_row(Fl_Table_Row *self, int row, int flag) {
-    LOCK(auto ret = self->select_row(row, flag);)
+    LOCK(auto ret = self->select_row(row, flag));
     return ret;
 }
 
 void Fl_Table_Row_select_all_rows(Fl_Table_Row *self, int flag) {
-    LOCK(self->select_all_rows(flag);)
+    LOCK(self->select_all_rows(flag));
 }
